@@ -8,15 +8,10 @@
  * @package    Secret
  * @subpackage UnitTests
  * @author     Michael Slusarz <slusarz@horde.org>
- * @license    http://www.fsf.org/copyleft/lgpl.html LGPL
+ * @license    http://www.horde.org/licenses/lgpl21 LGPL 2.1
  * @link       http://pear.horde.org/index.php?package=Secret
  */
 
-require_once 'Horde/Test/Autoload.php';
-
-/** Catch strict standards */
-error_reporting(E_ALL | E_STRICT);
-
 /** Needed for PEAR_Error. */
 require_once 'PEAR.php';
-require_once dirname(__FILE__) . '/Stub/Message.php';
\ No newline at end of file
+require_once __DIR__ . '/Stub/Message.php';
